#ifndef COMP_H
#define COMP_H

#include "ts_types.h"

/* a pointer to the array of vertices */
extern vertex *vs;

/* a pointer to the array of all sides (edges) of all triangles */
extern aedge *aes;

/* a pointer to the array of internal edges */
extern edge *es;

/* a pointer to the array of neurons (i.e. to the Hopfield network) */
extern neuron *hn;

/* the lengths of the corresponding arrays */
extern long vs_size, aes_size, es_size, hn_size;

/* the number of triangles read from the input file */
extern long ntr;

/* procedure comp performs the computation by Hopfield network and writes
 * the details about this performance into the file "comp.txt"
 *
 *     fname     the name of the input .obj file
 *     p_tt      a pointer to the variable that contains the convergence
 *               macroscopic time of the computation at the output
 *     tp0       initial temperature for simulated annealing
 *     end       stopping criterion (simulated annealing will stop if the
 *               ratio of the neurons that changed the state during current
 *               iteration is less than or equal to end)
 */
void comp ( char *fname, long *p_tt, double tp0, double end );

/* function trisgen generates an .objf representation
 *
 *     fname     the name of the input .obj file
 *     ofname    the name of the file in which the representation should be written
 *     fps       a pointer to the variable the output value of which is the number
 *               of triangle strips in the representation
 *     fminl     a pointer to the variable the output value of which is the length
 *               of the shortest triangle strip in the representation
 *     fmaxl     a pointer to the variable the output value of which is the length
 *               of the longest triangle strip in the representation
 */
int trisgen ( char *fname, char *ofname, long *fps, long *fminl, long *fmaxl );

#endif
